@@ -4,25 +4,25 @@
 class Array
 	# Generates a path using the elements of an array as path segments.
 	#
-	# `[a, b, c].as_path` is equivalent to `FilePath.join(a, b, c)`.
+	# `[a, b, c].as_path` is equivalent to `Filepath.join(a, b, c)`.
 	#
-	# @example FilePath from an array of strings
+	# @example Filepath from an array of strings
 	#
 	#     ["/", "foo", "bar"].as_path #=> </foo/bar>
 	#
-	# @example FilePath from an array of strings and other FilePaths
+	# @example Filepath from an array of strings and other Filepaths
 	#
 	#     server_dir = config["root_dir"] / "server"
 	#     ["..", config_dir, "secret"].as_path #=> <../config/server/secret>
 	#
-	# @return [FilePath] a new path generated using the element as path
+	# @return [Filepath] a new path generated using the element as path
 	#         segments
 	#
 	# @note FIXME: `#as_path` should be `#to_path` but that method name
 	#       is already used
 
 	def as_path
-		FilePath.join(self)
+		Filepath.join(self)
 	end
 
 
@@ -30,16 +30,16 @@ class Array
 	#
 	# The elements of the array must respond to `#as_path`.
 	#
-	# `ary.as_path` is equivalent to `FilePathList.new(ary)`.
+	# `ary.as_path` is equivalent to `FilepathList.new(ary)`.
 	#
-	# @return [FilePathList] a new path list containing the elements of
-	#                        the array as FilePaths
+	# @return [FilepathList] a new path list containing the elements of
+	#                        the array as Filepaths
 	#
 	# @see String#as_path
 	# @see Array#as_path
-	# @see FilePath#as_path
+	# @see Filepath#as_path
 
 	def as_path_list
-		FilePathList.new(self)
+		FilepathList.new(self)
 	end
 end
