@@ -2,25 +2,7 @@
 
 require 'rake/clean'
 
-FIXTURES_DIR = File.join(%w{spec fixtures})
-FIXTURES_FAKE_ENTRIES = [
-	'd1',
-		['d1', 'd11'],
-		['d1', 'd12'],
-		['d1', 'd13'],
-		['d1', 'f11'],
-		['d1', 'f12'],
-		['d1', 'l11'],
-	'd2',
-		['d2', 'd21'],
-		['d2', 'd22'],
-	'd3',
-	'f1',
-	'dx',
-	'p1',
-	'p2',
-	's1',
-].map { |entry| File.join(FIXTURES_DIR, *Array(entry)) }
+require File.join(File.dirname(__FILE__), 'fixtures')
 
 CLEAN.concat FIXTURES_FAKE_ENTRIES
 
